@@ -1,7 +1,7 @@
 from .util import check_type
 import json
 from json_cpp import JsonObject, JsonList
-
+from uuid import uuid1
 
 class Message(JsonObject):
 
@@ -9,6 +9,7 @@ class Message(JsonObject):
         JsonObject.__init__(self)
         self.header = header
         self.body = str(body)
+        self.id = str(uuid1())
         self._source = None
 
     def get_body(self, body_type: type = None):
@@ -17,11 +18,12 @@ class Message(JsonObject):
                 return JsonObject.load(self.body)
             elif issubclass(body_type, JsonObject) or issubclass(body_type, JsonList):
                 return body_type.parse(self.body)
+            elif body_type is str:
+                return self.body
+            elif body_type is bool:
+                return self.body == "success" or self.body == "true" or self.body == "1"
             else:
-                if body_type is str:
-                    return self.body
-                else:
-                    return body_type(json.loads(self.body))
+                return body_type(json.loads(self.body))
         else:
             return self.body
 
