@@ -82,19 +82,22 @@ class RouterProcess:
         RouterProcess.__handler = self
 
     @staticmethod
-    def __incoming_message(connection, router, message):
+    def __incoming_message__(connection: Connection, router: Router, message: Message):
         message._source = connection
         responses = router.route(message)
         if responses:
             for response in responses:
                 if isinstance(response, Message):
+                    response.id = message.id
                     connection.send(response)
                 elif isinstance(response, bool):
                     response_message = Message(message.header + "_response", "success" if response else "fail")
+                    response_message.id = message.id
                     connection.send(response_message)
                 else:
                     if response:
                         response_message = Message(message.header + "_response", str(response))
+                        response_message.id = message.id
                         connection.send(response_message)
 
     def __process__(self):
@@ -106,13 +109,12 @@ class RouterProcess:
                     if connection.state == Connection.State.Open:
                         message = connection.receive()
                         if message:
-                            new_thread = Thread(target=RouterProcess.__incoming_message, args=(connection, router, message))
-                            new_thread.start()
-                            self.incoming_messages_threads.append(new_thread)
+                            #RouterProcess.__incoming_message(connection, router, message)
+                            Thread(target=RouterProcess.__incoming_message__, args=(connection, router, message)).start()
                     else:
                         clean_up_required.append(index)
                 except:
-                    clean_up_required.append(index)
+                   clean_up_required.append(index)
 
             if clean_up_required:
                 RouterProcess.__mutex.acquire()
@@ -133,3 +135,5 @@ class RouterProcess:
                         to_remove.append(t)
                 for t in to_remove:
                     self.incoming_messages_threads.remove(t)
+
+
